@@ -5,9 +5,19 @@ use warnings;
 
 use Module::Want 0.6;
 
-$Locales::VERSION      = '0.31';    # change in POD
+$Locales::VERSION      = '0.34';    # change in POD
 $Locales::cldr_version = '2.0';     # change in POD
 
+$Locales::_UNICODE_STRINGS = 0;
+
+sub import {
+    my ( $c, %opt ) = @_;
+    if ( exists $opt{unicode} ) {
+        $Locales::_UNICODE_STRINGS = $opt{unicode};
+    }
+    return;
+}
+
 #### class methods ####
 
 my %singleton_stash;
@@ -1003,7 +1013,7 @@ sub normalize_for_key_lookup {
 sub plural_rule_string_to_javascript_code {
     my ( $plural_rule_string, $return ) = @_;
     my $perl = plural_rule_string_to_code( $plural_rule_string, $return );
-    $perl =~ s/sub { /function (n) {/;
+    $perl =~ s/sub \{ /function (n) {/;
     $perl =~ s/\$_\[0\]/n/g;
     $perl =~ s/ \(n \% ([0-9]+)\) \+ \(n-int\(n\)\) /n % $1/g;
     $perl =~ s/int\(/parseInt\(/g;
@@ -1176,7 +1186,7 @@ Locales - Methods for getting localized CLDR language/territory names (and a sub
 
 =head1 VERSION
 
-This document describes Locales version 0.31
+This document describes Locales version 0.33
 
 =head1 SYNOPSIS
 
@@ -1246,6 +1256,18 @@ As “soft locale” is a language-territory locale that does not fit the L</Sup
 
 For example “es-MX” does not fit the criteria but “es” does and “MX” is a valid territory code.
 
+=head1 To byte or not to byte, that is the question. Ok, I’ll byte …
+
+The CLDR data is in bytes, specifically utf-8.
+
+By default this module simply passes along the strings as bytes, which works fine in applications that don’t operate in character mode (i.e. that use utf8 byte strings instead of Unicode strings**).
+
+If you want Unicode strings instead you can do so by bringing in the module this way:
+
+    use Locales unicode => 1;
+
+[**] What is the difference between Unicode strings and utf-8 bytes strings you ask? See L<String::UnicodeUTF8> for more info.
+
 =head1 INTERFACE
 
 =head2 new()
@@ -1850,13 +1872,10 @@ The original, non CLDR based,  '::Base' based modules/interface in this distribu
 
 These modules were removed in version 0.15.
 
-=head1 BUGS AND LIMITATIONS
+=head1 BUGS AND FEATURES
 
-No bugs have been reported.
-
-Please report any bugs or feature requests regarding the Locales modules to
-C<bug-locales@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>.
+Please report any bugs or feature requests (and a pull request for bonus points)
+ through the issue tracker at L<https://github.com/drmuey/p5-Locales/issues>.
 
 Please report any bugs or feature requests regarding CLDR data as per
 L<http://cldr.unicode.org/index/bug-reports>.
